import { ICertificate } from 'aws-cdk-lib/aws-certificatemanager';
import { ClientVpnUserBasedAuthentication, DefaultInstanceTenancy, GatewayVpcEndpointOptions, IClientVpnConnectionHandler, NatProvider, SubnetSelection, TransportProtocol, Vpc, VpnConnectionOptions, VpnPort } from 'aws-cdk-lib/aws-ec2';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { ILogGroup, ILogStream } from 'aws-cdk-lib/aws-logs';
import { IConstruct } from 'constructs';
import { IpAddressManager } from '.';
import { NetworkIsolatedClientVpnEndpoint } from './network-isolated-client-vpn-endpoint';
import { FlowLogFormat, IIpamPool } from '../ec2';
import { ICidrAssignment, IIpv4CidrAssignment } from '../ec2/lib/cidr-assignment';
import { IVpcCidrBlock } from '../ec2/vpc-cidr-block';
export interface AddCidrBlockOptions {
    readonly cidrAssignment: ICidrAssignment;
}
export interface AddIsolatedClientVpnEndpointOptions {
    readonly authorizeAllUsersToVpcCidr?: boolean;
    readonly clientCertificate?: ICertificate;
    readonly clientConnectionHandler?: IClientVpnConnectionHandler;
    readonly clientLoginBanner?: string;
    readonly description?: string;
    readonly dnsServers?: string[];
    readonly logGroup?: ILogGroup;
    readonly logStream?: ILogStream;
    readonly logging?: boolean;
    readonly maxAzs?: number;
    readonly port?: VpnPort;
    readonly selfServicePortal?: boolean;
    readonly serverCertificate: ICertificate;
    readonly splitTunnel?: boolean;
    readonly subnetCidr?: IIpv4CidrAssignment;
    readonly transportProtocol?: TransportProtocol;
    readonly userBasedAuthentication?: ClientVpnUserBasedAuthentication;
    readonly vpnCidr?: IIpv4CidrAssignment;
}
export interface FlowLogOptions extends ec2.FlowLogOptions {
    readonly logFormatDefinition?: FlowLogFormat;
}
export interface FourTierNetworkProps {
    readonly addressManager?: IpAddressManager;
    readonly availabilityZones?: string[];
    readonly cidr?: IIpv4CidrAssignment;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly flowLogs?: {
        [id: string]: FlowLogOptions;
    };
    readonly gatewayEndpoints?: {
        [id: string]: GatewayVpcEndpointOptions;
    };
    readonly maxAzs?: number;
    readonly natGateways?: number;
    readonly natGatewayProvider?: NatProvider;
    readonly natGatewaySubnets?: SubnetSelection;
    readonly vpcName?: string;
    readonly vpnConnections?: {
        [id: string]: VpnConnectionOptions;
    };
    readonly vpnGateway?: boolean;
    readonly vpnGatewayAsn?: number;
    readonly vpnRoutePropagation?: SubnetSelection[];
}
export declare class FourTierNetwork extends Vpc {
    readonly addressManager?: IpAddressManager;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly ipamPool?: IIpamPool;
    readonly maxAzs?: number;
    readonly netmask: number;
    readonly vpcName?: string;
    constructor(scope: IConstruct, id: string, props?: FourTierNetworkProps);
    addCidrBlock(id: string, options: AddCidrBlockOptions): IVpcCidrBlock;
    addIsolatedClientVpnEndpoint(id: string, options: AddIsolatedClientVpnEndpointOptions): NetworkIsolatedClientVpnEndpoint;
    addVpcFlowLog(id: string, options?: FlowLogOptions): ec2.FlowLog;
}
