import { FlowLogField } from './flow-log-field';
export declare class FlowLogFormat {
    /**
         * The basic set of fields included in most flow logs. This is the default
         * format that is used when new flow logs are created without specifying a
         * custom format.
         */
    static readonly V2: FlowLogFormat;
    /**
         * Includes all the fields available in V2. Adds fields to help identify
         * AWS resources associated with traffic as well as fields that give
         * greater visibility into protocol specific details.
         */
    static readonly V3: FlowLogFormat;
    /**
         * Includes all the fields available in V3. Adds fields for identifying
         * the region and availabilty zone associated with flows, as well as
         * details related to extended zones such as Wavelength, Outputs, and
         * Local Zones.
         */
    static readonly V4: FlowLogFormat;
    /**
         * Includes all the fields available in V4. Adds fields to help identify
         * related AWS services and improve visibility into packet routing.
         */
    static readonly V5: FlowLogFormat;
    /**
       * Parses a flow log format template string to create a new FlowLogFormat
       * object.
       *
       * @param template A flow log template string to parse.
       * @returns A FlowLogFormat object representing the passed template.
       */
    static fromTemplate(template: string): FlowLogFormat;
    /**
         * The fields that make up the flow log format, in the order that they
         * should appear in the log entries.
         */
    readonly fields: FlowLogField[];
    /**
         * The rendered format string in the format expected by AWS when creating
         * a new Flow Log.
         */
    readonly template: string;
    /**
         * Creates a new instance of the FlowLogFormat class.
         *
         * @param fields The fields that should be included in the flow log output.
         */
    constructor(...fields: FlowLogField[]);
    /**
         * Adds a new field to the flow log output. New fields are added at the
         * end of a log entry after all the other fields that came before it.
         *
         * @param field The field to add to the FlowLogFormat.
         */
    addField(field: FlowLogField): void;
}
