import { ArnFormat } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
import { AdvertiseService } from '.';
import { IIpamPool } from './ipam-pool';
import { IIpamScope, IpamScopeAttributes } from './ipam-scope';
export interface IPublicIpamScope extends IIpamScope {
    addAwsProvidedIpv6Pool(id: string, options: AddAwsProvidedIpv6PoolOptions): IIpamPool;
    addByoipIpv4Pool(id: string, options: AddByoipIpv4PoolOptions): IIpamPool;
    addByoipIpv6Pool(id: string, options: AddByoipIpv6PoolOptions): IIpamPool;
}
export interface AddAwsProvidedIpv6PoolOptions {
    readonly defaultNetmaskLength?: number;
    readonly description?: string;
    readonly locale: string;
    readonly maxNetmaskLength?: number;
    readonly minNetmaskLength?: number;
    readonly name?: string;
    readonly netmask?: number;
    readonly tagRestrictions?: {
        [key: string]: string;
    };
}
export interface AddByoipIpv4PoolOptions {
    readonly advertiseService?: AdvertiseService;
    readonly defaultNetmaskLength?: number;
    readonly description?: string;
    readonly locale?: string;
    readonly maxNetmaskLength?: number;
    readonly minNetmaskLength?: number;
    readonly name?: string;
    readonly tagRestrictions?: {
        [key: string]: string;
    };
}
export interface AddByoipIpv6PoolOptions {
    readonly advertiseService?: AdvertiseService;
    readonly defaultNetmaskLength?: number;
    readonly description?: string;
    readonly locale?: string;
    readonly maxNetmaskLength?: number;
    readonly minNetmaskLength?: number;
    readonly name?: string;
    readonly publiclyAdvertisable?: boolean;
    readonly tagRestrictions?: {
        [key: string]: string;
    };
}
export declare class PublicIpamScope {
    /**
     * The format for Amazon Resource Names (ARN's) for IPAM scope resources.
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing IPAM scope by specifying its Amazon Resource Name
     * (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeArn The ARN of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeArn(scope: IConstruct, id: string, ipamScopeArn: string): IPublicIpamScope;
    /**
     * Imports an existing IAPM scope by explicitly specifying its attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeAttributes(scope: IConstruct, id: string, attrs: IpamScopeAttributes): IPublicIpamScope;
    /**
     * Imports an existing IPAM scope by explicitly specifying its AWS generated
     * ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeId The AWS generated ID of the existing IPAM scope to be
     * imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeId(scope: IConstruct, id: string, ipamScopeId: string): IPublicIpamScope;
}
